pub struct FewShotChatMessagePromptTemplate { /* private fields */ }Expand description
A few-shot chat message prompt template that injects examples before the user query.
Each example is formatted as a Human message (input) followed by an AI message (output). An optional prefix system message can be provided.
Implementations
Sourceimpl FewShotChatMessagePromptTemplate
impl FewShotChatMessagePromptTemplate
pub fn new(examples: Vec<FewShotExample>, suffix: PromptTemplate) -> Self
pub fn with_prefix(self, prefix: PromptTemplate) -> Self
pub fn format( &self, values: &HashMap<String, String>, ) -> Result<Vec<Message>, SynapticError>