pub struct PromptTemplate { /* private fields */ }Implementations
Sourceimpl PromptTemplate
impl PromptTemplate
pub fn new(template: impl Into<String>) -> Self
Sourcepub fn with_partial(
self,
key: impl Into<String>,
value: impl Into<String>,
) -> Self
pub fn with_partial( self, key: impl Into<String>, value: impl Into<String>, ) -> Self
Set a partial variable that will be used as a default during rendering. Provided values at render time take precedence over partial variables.
pub fn render( &self, values: &HashMap<String, String>, ) -> Result<String, PromptError>